@@ -1,10 +1,10 @@
 from CyLPModel import CyLPArray
-from CyLPModel import cylpExpr
-from CyLPModel import cylpVar
+from CyLPModel import CyLPExpr
+from CyLPModel import CyLPVar
 from CyLPModel import IndexFactory
-from CyLPModel import cylpConstraint
-#from cylpTypes import cylpVar
+from CyLPModel import CyLPConstraint
+#from cylpTypes import CyLPVar
 #from cylpTypes import CyLPArray
-#from cylpTypes import cylpExpr
+#from cylpTypes import CyLPExpr
 #from cylpTypes import getCoinInfinity
 from CyLPModel import CyLPModel
